@@ -49,7 +49,6 @@
 #define KEY_GNOME_ACCESSIBILITY "toolkit-accessibility"
 #define KEY_GNOME_ANIMATIONS "enable-animations"
 #define KEY_GNOME_CURSOR_THEME "cursor-theme"
-#define KEY_GNOME_CURSOR_SIZE "cursor-size"
 
 /* These are the different schemas we are keeping
  * a GSettings instance for */
@@ -95,7 +94,7 @@ static gboolean force_fullscreen = TRUE;
 static gboolean alt_tab_thumbnails = FALSE;
 
 static GDesktopVisualBellType visual_bell_type = G_DESKTOP_VISUAL_BELL_FULLSCREEN_FLASH;
-static MetaButtonLayout button_layout;
+static gchar *button_layout;
 
 static MetaPlacementMode placement_mode = META_PLACEMENT_MODE_SMART;
 
@@ -435,13 +434,6 @@ static MetaIntPreference preferences_int[] =
       },
       &auto_raise_delay
     },
-    {
-      { KEY_GNOME_CURSOR_SIZE,
-        SCHEMA_INTERFACE,
-        META_PREF_CURSOR_SIZE,
-      },
-      &cursor_size
-    },
     { { NULL, 0, 0 }, NULL },
   };
 
@@ -767,6 +759,38 @@ queue_changed (MetaPreference pref)
                                     changed_idle_handler, NULL, NULL);
 }
 
+static void
+gtk_cursor_theme_size_changed (GtkSettings *settings,
+                               GParamSpec  *pspec,
+                               gpointer     user_data)
+{
+  gint size;
+
+  g_object_get (settings, "gtk-cursor-theme-size", &size, NULL);
+
+  if (size == 0)
+    size = 24;
+
+  if (size != cursor_size)
+    {
+      cursor_size = size;
+      queue_changed (META_PREF_CURSOR_SIZE);
+    }
+}
+
+static void
+init_gtk_cursor_theme_size (void)
+{
+  GtkSettings *settings;
+
+  settings = gtk_settings_get_default ();
+
+  g_signal_connect (settings, "notify::gtk-cursor-theme-size",
+                    G_CALLBACK (gtk_cursor_theme_size_changed), NULL);
+
+  gtk_cursor_theme_size_changed (settings, NULL, NULL);
+}
+
 static gboolean
 in_desktop (const gchar *name)
 {
@@ -917,8 +941,6 @@ meta_prefs_init (void)
                     G_CALLBACK (settings_changed), NULL);
   g_signal_connect (settings, "changed::" KEY_GNOME_CURSOR_THEME,
                     G_CALLBACK (settings_changed), NULL);
-  g_signal_connect (settings, "changed::" KEY_GNOME_CURSOR_SIZE,
-                    G_CALLBACK (settings_changed), NULL);
   g_hash_table_insert (settings_schemas, g_strdup (SCHEMA_INTERFACE), settings);
 
   /* Pick up initial values. */
@@ -930,6 +952,7 @@ meta_prefs_init (void)
   init_bindings ();
   init_workspace_names ();
 
+  init_gtk_cursor_theme_size ();
   init_gtk_decoration_layout ();
   init_gtk_theme_name ();
 }
@@ -1176,43 +1199,16 @@ mouse_button_mods_handler (GVariant *value,
   return TRUE;
 }
 
-static gboolean
-button_layout_equal (const MetaButtonLayout *a,
-                     const MetaButtonLayout *b)
-{
-  int i;
-
-  i = 0;
-  while (i < META_BUTTON_FUNCTION_LAST)
-    {
-      if (a->left_buttons[i] != b->left_buttons[i])
-        return FALSE;
-      if (a->right_buttons[i] != b->right_buttons[i])
-        return FALSE;
-      if (a->left_buttons_has_spacer[i] != b->left_buttons_has_spacer[i])
-        return FALSE;
-      if (a->right_buttons_has_spacer[i] != b->right_buttons_has_spacer[i])
-        return FALSE;
-      i++;
-    }
-
-  return TRUE;
-}
-
 static void
 update_button_layout (const gchar *string_value)
 {
-  gboolean invert;
-  MetaButtonLayout new_layout;
+  if (g_strcmp0 (button_layout, string_value) == 0)
+    return;
 
-  invert = meta_ui_get_direction() == META_UI_DIRECTION_RTL;
-  new_layout = meta_button_layout_new (string_value, invert);
+  g_free (button_layout);
+  button_layout = g_strdup (string_value);
 
-  if (!button_layout_equal (&button_layout, &new_layout))
-    {
-      button_layout = new_layout;
-      emit_changed (META_PREF_BUTTON_LAYOUT);
-    }
+  emit_changed (META_PREF_BUTTON_LAYOUT);
 }
 
 static gboolean
@@ -1595,10 +1591,10 @@ meta_prefs_change_workspace_name (int         num,
                         g_variant_builder_end (&builder));
 }
 
-void
-meta_prefs_get_button_layout (MetaButtonLayout *button_layout_p)
+const gchar *
+meta_prefs_get_button_layout (void)
 {
-  *button_layout_p = button_layout;
+  return button_layout;
 }
 
 gboolean
