@@ -1370,7 +1370,6 @@ meta_screen_ensure_tab_popup (MetaScreen      *screen,
     }
 
   screen->tab_popup = meta_ui_tab_popup_new (entries,
-                                             screen->number,
                                              len,
                                              5, /* FIXME */
                                              TRUE);
@@ -1442,7 +1441,6 @@ meta_screen_ensure_workspace_popup (MetaScreen *screen)
     }
 
   screen->tab_popup = meta_ui_tab_popup_new (entries,
-                                             screen->number,
                                              len,
                                              layout.cols,
                                              FALSE);
@@ -1464,8 +1462,7 @@ meta_screen_tile_preview_update_timeout (gpointer data)
   screen->tile_preview_timeout_id = 0;
 
   if (!screen->tile_preview)
-    screen->tile_preview = meta_tile_preview_new (screen->number,
-                                                  composited);
+    screen->tile_preview = meta_tile_preview_new (composited);
 
   if (window)
     {
