@@ -29,7 +29,7 @@
 
 Display *meta_display_get_xdisplay (MetaDisplay *display);
 MetaCompositor *meta_display_get_compositor (MetaDisplay *display);
-GSList *meta_display_get_screens (MetaDisplay *display);
+MetaScreen *meta_display_get_screen (MetaDisplay *display);
 
 gboolean meta_display_has_shape (MetaDisplay *display);
 
