@@ -49,6 +49,8 @@ void meta_ui_init (int *argc, char ***argv);
 
 Display* meta_ui_get_display (void);
 
+gint     meta_ui_get_screen_number (void);
+
 void meta_ui_add_event_func    (Display       *xdisplay,
                                 MetaEventFunc  func,
                                 gpointer       data);
@@ -74,14 +76,14 @@ void meta_ui_get_frame_mask (MetaUI  *ui,
                              guint    height,
                              cairo_t *cr);
 
-Window meta_ui_create_frame_window (MetaUI *ui,
+Window meta_ui_create_frame_window (MetaUI  *ui,
                                     Display *xdisplay,
-                                    Visual *xvisual,
-				    gint x,
-				    gint y,
-				    gint width,
-				    gint height,
-				    gint screen_no);
+                                    Visual  *xvisual,
+                                    gint     x,
+                                    gint     y,
+                                    gint     width,
+                                    gint     height);
+
 void meta_ui_destroy_frame_window (MetaUI *ui,
 				   Window  xwindow);
 void meta_ui_move_resize_frame (MetaUI *ui,
@@ -157,6 +159,7 @@ gboolean  meta_ui_window_should_not_cause_focus (Display *xdisplay,
                                                  Window   xwindow);
 
 void meta_ui_reload_theme (void);
+void meta_ui_update_button_layout (void);
 
 /* Not a real key symbol but means "key above the tab key"; this is
  * used as the default keybinding for cycle_group.
